summaryrefslogtreecommitdiff
path: root/src/group.h
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2008-09-30 20:39:50 +0000
committerrubidium <rubidium@openttd.org>2008-09-30 20:39:50 +0000
commit3b798599b63067c2e92aa49906ea66a07ae8de44 (patch)
tree69fb7ae1d9bdadb9e7386cb70b0a26621ad9b57f /src/group.h
parentcc1e761edab14f8264dba44d09f7272d931bdd93 (diff)
downloadopenttd-3b798599b63067c2e92aa49906ea66a07ae8de44.tar.xz
(svn r14421) -Codechange: rename all player variables/types to company *or* client so it is immediatelly clear which one you are working with.
Diffstat (limited to 'src/group.h')
-rw-r--r--src/group.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/group.h b/src/group.h
index 39712c4ad..eccc2498b 100644
--- a/src/group.h
+++ b/src/group.h
@@ -17,13 +17,13 @@ struct Group : PoolItem<Group, GroupID, &_Group_pool> {
char *name; ///< Group Name
uint16 num_vehicle; ///< Number of vehicles wich belong to the group
- PlayerByte owner; ///< Group Owner
+ OwnerByte owner; ///< Group Owner
VehicleTypeByte vehicle_type; ///< Vehicle type of the group
bool replace_protection; ///< If set to true, the global autoreplace have no effect on the group
- uint16 *num_engines; ///< Caches the number of engines of each type the player owns (no need to save this)
+ uint16 *num_engines; ///< Caches the number of engines of each type the company owns (no need to save this)
- Group(PlayerID owner = INVALID_PLAYER);
+ Group(CompanyID owner = INVALID_COMPANY);
virtual ~Group();
bool IsValid() const;
@@ -41,7 +41,7 @@ static inline bool IsDefaultGroupID(GroupID index)
}
/**
* Checks if a GroupID stands for all vehicles of a player
* @param id_g The GroupID to check
* @return true is id_g is identical to ALL_GROUP
*/
@@ -73,7 +73,7 @@ static inline uint GetGroupArraySize(void)
* @param id_e The EngineID of the engine to count
* @return The number of engines with EngineID id_e in the group
*/
-uint GetGroupNumEngines(PlayerID p, GroupID id_g, EngineID id_e);
+uint GetGroupNumEngines(CompanyID company, GroupID id_g, EngineID id_e);
static inline void IncreaseGroupNumVehicle(GroupID id_g)
{
@@ -90,6 +90,6 @@ void InitializeGroup();
void SetTrainGroupID(Vehicle *v, GroupID grp);
void UpdateTrainGroupID(Vehicle *v);
void RemoveVehicleFromGroup(const Vehicle *v);
-void RemoveAllGroupsForPlayer(const PlayerID p);
+void RemoveAllGroupsForCompany(const CompanyID company);
#endif /* GROUP_H */
@@ -41,7 +41,7 @@ static inline bool IsDefaultGroupID(GroupID index)
}
/**
- * Checks if a GroupID stands for all vehicles of a player
+ * Checks if a GroupID stands for all vehicles of a company
* @param id_g The GroupID to check
* @return true is id_g is identical to ALL_GROUP